changeset 12232:f42795956a18

Comment change.
author Richard M. Stallman <rms@gnu.org>
date Wed, 14 Jun 1995 23:18:50 +0000
parents c00af359fde5
children 9a87c5ce0802
files src/systty.h
diffstat 1 files changed, 3 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/src/systty.h	Wed Jun 14 23:17:44 1995 +0000
+++ b/src/systty.h	Wed Jun 14 23:18:50 1995 +0000
@@ -317,11 +317,10 @@
    of the tty on FD in *P.  Return zero if all's well, or -1 if we ran
    into an error we couldn't deal with.
 
-   EMACS_SET_TTY (int FD, struct emacs_tty *P, int waitp)
+   EMACS_SET_TTY (int FD, struct emacs_tty *P, int flushp)
    sets the parameters of the tty on FD according to the contents of
-   *P.  If waitp is non-zero, we wait for all queued output to be
-   written before making the change; otherwise, we forget any queued
-   input and make the change immediately.
+   *P.  If flushp is non-zero, we discard queued input to be
+   written before making the change.
    Return 0 if all went well, and -1 if anything failed.
 
    EMACS_TTY_TABS_OK (struct emacs_tty *P) is false iff the kernel